@@ -459,7 +459,7 @@ pub enum ExternalMsg {
     /// can be used.
     /// You may need to pass `ExplorePwd` depening on the expectation.
     ///
-    /// Type: { Call = "string" }
+    /// Type: { Call = { command = string, args = { "list", "of", "string" } }
     ///
     /// Example:
     ///
@@ -1423,8 +1423,16 @@ impl PartialEq for CmpRegex {
 
 impl Eq for CmpRegex {}
 
-#[derive(Debug, Clone, Eq, Hash, PartialEq, Serialize, Deserialize)]
+// See https://github.com/sayanarijit/xplr/issues/503
+#[derive(Debug, Deserialize)]
 #[serde(deny_unknown_fields)]
+struct NodeFilterApplicableDeserializer {
+    pub filter: NodeFilter,
+    pub input: String,
+}
+
+#[derive(Debug, Clone, Eq, Hash, PartialEq, Serialize, Deserialize)]
+#[serde(deny_unknown_fields, from = "NodeFilterApplicableDeserializer")]
 pub struct NodeFilterApplicable {
     pub filter: NodeFilter,
     pub input: String,
@@ -1433,6 +1441,12 @@ pub struct NodeFilterApplicable {
     pub regex: Option<CmpRegex>,
 }
 
+impl From<NodeFilterApplicableDeserializer> for NodeFilterApplicable {
+    fn from(f: NodeFilterApplicableDeserializer) -> Self {
+        NodeFilterApplicable::new(f.filter, f.input)
+    }
+}
+
 impl NodeFilterApplicable {
     pub fn new(filter: NodeFilter, input: String) -> Self {
         use NodeFilter::*;
